/* @(#) inquire.h  version:1.5  dated:84/11/14 */
/*
 * C-GKS
 *
 * COPYRIGHT 1984 - CENTRUM VOOR WISKUNDE EN INFORMATICA
 */

/*
 * SCCS file:	SCCS/s.inquire.h
 * SCCS id :	inquire.h 1.5
 * Last edited:	10/19/84 13:57:44
 *
 * Author:	Behr de Ruiter, Paul ten Hagen
 *         	Centrum voor Wiskunde en Informatica
 *         	Amsterdam
 */

/***************************************************************
This file contains the macro definitions for the inquiry functions.

The C binding almost completely eliminates inquiry functions as
such. The application is provided with the data type definitions of 
the structures implementing the various GKS statelists. Whenever a
statelist is created, for example by OPEN_GKS or 
OPEN_SEGMENT, the corresponding
function returns the address of the newly created statelist structure.

The application could thus refer to the fields of the structure
directly. It would seem attractive to replace the multitude of 
inquiry functions with a function for each statelist whose arguments
were the statelist pointer and the field name within it, but:
- fieldnames alone are not valid expressions in C
- specifying the type of the value returned by such a function is  
  problematic.
Instead the application invokes inquiry macros, looking like
functions with these arguments. They are converted into in-line
C by the preprocessor and thereby escape the restrictions on the
use of field names.
So that they may safely be called from error handling routines,
GKS inquiry functions  do not themselves generate errors.
Instead, they set an output parameter indicating whether the value
inquired for is available. In C, this precaution is not required.
If the application has a valid statelist address, then the value is
available. Otherwise, the value is both unavailable and inaccessible.
********************************************************************/

	
/*****************INQUIRE OPERATING STATE **************************/

extern GksState gkstate;

#define inq_state() \
	gkstate

/*****************INQUIRE GKS DESCRIPTION TABLE ********************/

extern Gksd *gksd;

#define inq_gkd(fn) \
	 	gksd->fn

/*****************INQUIRE GKS STATE LIST ***************************/

#define inq_gks(gk, fn) \
		 gk->fn

/*****************INQUIRE WORKSTATION STATE LIST *******************/
#define	inq_wss(ws, fn) \
		 ws->fn

/*****************INQUIRE WORKSTATION DESCRIPTION TABLE ************/

#define	inq_wsd(wd, fn) \
		wd->fn

/*****************INQUIRE SEGMENT STATELIST ************************/

#define inq_seg(sg, fn) \
		sg->fn
